package com.rootsoft.customtoast;

import android.content.Context;
import android.graphics.Bitmap;
import android.os.CountDownTimer;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.Toast;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.Author;
import anywheresoftware.b4a.BA.Permissions;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;

@ShortName("CustomToast")
@Permissions(values={"android.permission.WRITE_SECURE_SETTINGS"})
@Author("XverhelstX")
@Version(1.1f)

public class CustomToast {
	
	private BA ba; 
	
    /**
     * Initializes the CustomToast Library.
     *
     */
	
	public void Initialize(BA ba)
	{
	  this.ba = ba;
	  
	}
	
	/**
	 * Shows a custom toastmessage
	 * @param message the message to be displayed. (a string)
	 * @param duration in milliseconds
	 * a Gravity constant, an x-position offset, and a y-position offset.
	 * For example, if you decide that the toast should appear in the top corner.
	 * (Gravity.TOP, 0, 0)
	 */
	public void Show(CharSequence message, int duration, int gravity, int xOffset, int yOffset) {
		
		@SuppressWarnings("static-access")
		Context context = ba.applicationContext.getApplicationContext();
		final Toast toast = Toast.makeText(context, message, 0);
		toast.setGravity(gravity, xOffset, yOffset);
		
		new CountDownTimer(duration - 1000 , 1000)
		{

		    public void onTick(long millisUntilFinished) {toast.show();}
		    public void onFinish() {toast.show();}

		}.start();
		
		
	}
	
	/**
	 * Shows a custom toastmessage with a bitmap.
	 * @param message the message to be displayed. (a string)
	 * @param duration in milliseconds
	 * a Gravity constant, an x-position offset, and a y-position offset.
	 * For example, if you decide that the toast should appear in the top corner.
	 * (Gravity.TOP, 0, 0)
	 */
	public void ShowBitmap(CharSequence message, int duration, int gravity, int xOffset, int yOffset, Bitmap bm) {
		
		@SuppressWarnings("static-access")
		Context context = ba.applicationContext.getApplicationContext();
		final Toast toast = Toast.makeText(context, message, 0);
		toast.setGravity(gravity, xOffset, yOffset);
		
		LinearLayout toastView = (LinearLayout) toast.getView();
		ImageView imageCodeProject = new ImageView(ba.applicationContext.getApplicationContext());
		imageCodeProject.setImageBitmap(bm);
		toastView.addView(imageCodeProject, 0);
		
		new CountDownTimer(duration - 1000 , 1000)
		{

		    public void onTick(long millisUntilFinished) {toast.show();}
		    public void onFinish() {toast.show();}

		}.start();
		
		
	}
	

}
